import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.util.Properties;

import org.junit.Assert;
import org.junit.Test;

/**
 * 
 * @author otomczak
 * 
 */
public class InvalidTimestampFormatTest {

    static {

        try {

            Class.forName("com.mysql.jdbc.Driver");

        } catch (Exception ex) {

            throw new IllegalStateException(ex);

        }

    }

    /**
     * 
     * @throws Exception
     */
    @Test
    public void testSelectFailsBecauseTimestampFormatIsInvalid() throws Exception {

        final Properties connectionProps = new Properties();
        connectionProps.load(InvalidTimestampFormatTest.class.getResourceAsStream("/connection.properties"));

        final Connection conn = DriverManager.getConnection("jdbc:mysql://127.0.0.1/otomczak_mysql_jdbc_test", connectionProps);

        final PreparedStatement select = conn
                .prepareStatement("select TTB_FLAG, TTB_DATE from DB_TEST_TABLE force index (IDX_FLAG_DATE) where TTB_FLAG = TRUE AND TTB_DATE >= ? ORDER BY TTB_DATE DESC");
        select.setTimestamp(1, new java.sql.Timestamp(110, 2, 22, 15, 34, 44, 0)); // '2010-03-22 15:34:44'

        // select TTB_FLAG, TTB_DATE from DB_TEST_TABLE force index (IDX_FLAG_DATE) where TTB_FLAG = TRUE AND TTB_DATE >= '2010-03-22 15:34:44';

        final ResultSet resultSet = select.executeQuery();
        Assert.assertTrue(resultSet.next());
        Assert.assertTrue(resultSet.getBoolean(1));
        Assert.assertEquals(new java.sql.Timestamp(110, 2, 22, 15, 37, 04, 0), resultSet.getTimestamp(2));
        Assert.assertTrue(resultSet.next());
        Assert.assertTrue(resultSet.getBoolean(1));
        Assert.assertEquals(new java.sql.Timestamp(110, 2, 22, 15, 37, 02, 0), resultSet.getTimestamp(2));
        Assert.assertTrue(resultSet.next());
        Assert.assertTrue(resultSet.getBoolean(1));
        Assert.assertEquals(new java.sql.Timestamp(110, 2, 22, 15, 36, 53, 0), resultSet.getTimestamp(2));
        Assert.assertTrue(resultSet.next());
        Assert.assertTrue(resultSet.getBoolean(1));
        Assert.assertEquals(new java.sql.Timestamp(110, 2, 22, 15, 36, 50, 0), resultSet.getTimestamp(2));
        // this last row is not found
        Assert.assertTrue(resultSet.next());
        Assert.assertTrue(resultSet.getBoolean(1));
        Assert.assertEquals(new java.sql.Timestamp(110, 2, 22, 15, 34, 44, 0), resultSet.getTimestamp(2));
        Assert.assertFalse(resultSet.next());

    }

}
